%global prg_suffix openssl

Summary: A utility for getting files from remote servers (FTP, HTTP, and others)
Name: curl-%{prg_suffix}
Version: 7.68.0
Release: 1%{?dist}
License: MIT
Source: https://curl.haxx.se/download/curl-%{version}.tar.gz
URL: https://curl.haxx.se/
BuildRequires: automake autoconf libtool make
BuildRequires: coreutils
BuildRequires: gcc
BuildRequires: groff
BuildRequires: krb5-devel
BuildRequires: libidn2-devel
BuildRequires: libmetalink-devel
BuildRequires: libpsl-devel
BuildRequires: libssh-devel
BuildRequires: openssh-clients
BuildRequires: openssh-server
BuildRequires: pkgconfig
BuildRequires: python-devel
BuildRequires: sed
BuildRequires: stunnel
BuildRequires: zlib-devel
BuildRequires: openssl-devel

# needed to compress content of tool_hugehelp.c after changing curl.1 man page
BuildRequires: perl(IO::Compress::Gzip)

# using an older version of libcurl could result in CURLE_UNKNOWN_OPTION
Requires: libcurl_%{prg_suffix}%{?_isa} >= %{version}-%{release}

# require at least the version of libpsl that we were built against,
# to ensure that we have the necessary symbols available (#1631804)
%global libpsl_version %(pkg-config --modversion libpsl 2>/dev/null || echo 0)

# require at least the version of libssh that we were built against,
# to ensure that we have the necessary symbols available (#525002, #642796)
%global libssh_version %(pkg-config --modversion libssh 2>/dev/null || echo 0)

%description
curl is a command line tool for transferring data with URL syntax, supporting
FTP, FTPS, HTTP, HTTPS, SCP, SFTP, TFTP, TELNET, DICT, LDAP, LDAPS, FILE, IMAP,
SMTP, POP3 and RTSP.  curl supports SSL certificates, HTTP POST, HTTP PUT, FTP
uploading, HTTP form based upload, proxies, cookies, user+password
authentication (Basic, Digest, NTLM, Negotiate, kerberos...), file transfer
resume, proxy tunneling and a busload of other useful tricks. 

%package -n libcurl_%{prg_suffix}
Summary: A library for getting files from web servers
Requires: libpsl%{?_isa} >= %{libpsl_version}
Requires: libssh%{?_isa} >= %{libssh_version}
Requires: openssl-libs%{?_isa}

%description -n libcurl_%{prg_suffix}
libcurl is a free and easy-to-use client-side URL transfer library, supporting
FTP, FTPS, HTTP, HTTPS, SCP, SFTP, TFTP, TELNET, DICT, LDAP, LDAPS, FILE, IMAP,
SMTP, POP3 and RTSP. libcurl supports SSL certificates, HTTP POST, HTTP PUT,
FTP uploading, HTTP form based upload, proxies, cookies, user+password
authentication (Basic, Digest, NTLM, Negotiate, Kerberos4), file transfer
resume, http proxy tunneling and more.

%package -n libcurl_%{prg_suffix}-devel
Summary: Files needed for building applications with libcurl
Requires: libcurl_%{prg_suffix}%{?_isa} = %{version}-%{release}

%description -n libcurl_%{prg_suffix}-devel
The libcurl-devel package includes header files and libraries necessary for
developing programs which use the libcurl library. It contains the API
documentation of the library, too.

%prep

%setup -q -n curl-%{version}

# This is the special souce, the autopoo magic developed by Oden Eriksson at Mandriva
for i in `find -type f -name "Makefile*"`; do
    perl -pi -e "s|libcurl\.la|libcurl_%{prg_suffix}\.la|g" $i
    perl -pi -e "s|libcurl_la_|libcurl_%{prg_suffix}_la_|g" $i
done

autoreconf -fi

%build

%configure \
    --program-suffix=_%{prg_suffix} \
    --disable-static \
    --enable-symbol-hiding \
    --enable-ipv6 \
    --enable-threaded-resolver \
    --without-gssapi \
    --without-nghttp2 \
    --with-ca-bundle=/etc/pki/tls/certs/ca-bundle.crt \
    --disable-ldap \
    --disable-ldaps \
    --enable-manual \
    --without-brotli \
    --with-libidn2 \
    --with-libmetalink \
    --with-libpsl \
    --with-libssh


# avoid using rpath
sed -e 's/^runpath_var=.*/runpath_var=/' -e 's/^hardcode_libdir_flag_spec=".*"$/hardcode_libdir_flag_spec=""/' libtool

make %{?_smp_mflags} V=1

%install

make DESTDIR=%{buildroot} INSTALL="install -p" install

# renaming battle
#mv %{buildroot}%{_bindir}/curl %{buildroot}%{_bindir}/curl_%{prg_suffix}
mv %{buildroot}%{_includedir}/curl %{buildroot}%{_includedir}/curl_%{prg_suffix}

#mv %{buildroot}%{_bindir}/curl-config %{buildroot}%{_bindir}/curl_%{prg_suffix}-config
mv %{buildroot}%{_libdir}/pkgconfig/libcurl.pc %{buildroot}%{_libdir}/pkgconfig/libcurl_%{prg_suffix}.pc

perl -pi -e "s|-lcurl|-lcurl_openssl|g" %{buildroot}%{_bindir}/curl-config_%{prg_suffix} \
    %{buildroot}%{_libdir}/pkgconfig/libcurl_%{prg_suffix}.pc

perl -pi -e "s|libcurl\.a|libcurl_%{prg_suffix}\.a|g" %{buildroot}%{_bindir}/curl-config_%{prg_suffix}

# cleanup
rm -f %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_mandir}
rm -rf %{buildroot}%{_datadir}/aclocal

%files
%{_bindir}/curl_%{prg_suffix}

%files -n libcurl_%{prg_suffix}
%doc CHANGES COPYING README RELEASE-NOTES
%{_libdir}/libcurl_%{prg_suffix}.so.4
%{_libdir}/libcurl_%{prg_suffix}.so.4.[0-9].[0-9]

%files -n libcurl_%{prg_suffix}-devel
%{_bindir}/curl-config_%{prg_suffix}
%{_includedir}/curl_%{prg_suffix}
%{_libdir}/libcurl_%{prg_suffix}.so
%{_libdir}/pkgconfig/libcurl_%{prg_suffix}.pc

%changelog
* Thu Jan 23 2020 Oden Eriksson <oe@nux.se> 7.68.0-1
- 7.68.0

* Thu Aug 01 2019 Oden Eriksson <oe@nux.se> 7.65.3-1
- 7.65.3

* Wed May 22 2019 Oden Eriksson <oe@nux.se> 7.65.0-1
- rename the package using a rpm macro
- rename certain files
- add renamed devel files

* Wed May 22 2019 Oden Eriksson <oe@nux.se> 7.65.0-1
- 7.65.0

* Tue Apr 30 2019 Oden Eriksson <oe@nux.se> 7.64.1-1
- 7.64.1
- build against system openssl
- also provide a devel sub package

* Fri Mar 08 2019 Oden Eriksson <oe@nux.se> 7.64.0-1
- initial package

